@@ -22,7 +22,7 @@
 
 #include "gswitchit_plugin_manager.h"
 
-#define FOR_EACH_INITED_PLUGIN() \
+#define FOREACH_INITED_PLUGIN() \
 { \
   GSList *prec; \
   for( prec = manager->initedPluginRecs; prec != NULL; prec = prec->next ) \
@@ -32,25 +32,25 @@
     if( plugin != NULL ) \
     {
 
-#define END_FOR_EACH_INITED_PLUGIN() \
+#define NEXT_INITED_PLUGIN() \
     } \
   } \
 }
 
 static void
-_GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
-				      manager, const char *dirname)
+_GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *manager,
+				      const char *dirname)
 {
 	GDir *dir = g_dir_open (dirname, 0, NULL);
 	const gchar *filename;
 	if (dir == NULL)
 		return;
 
-	XklDebug (100, "Scanning [%s]...\n", dirname);
+	xkl_debug (100, "Scanning [%s]...\n", dirname);
 	while ((filename = g_dir_read_name (dir)) != NULL) {
 		gchar *fullPath =
 		    g_build_filename (dirname, filename, NULL);
-		XklDebug (100, "Loading plugin module [%s]...\n",
+		xkl_debug (100, "Loading plugin module [%s]...\n",
 			  fullPath);
 		if (fullPath != NULL) {
 			GModule *module = g_module_open (fullPath, 0);
@@ -68,7 +68,7 @@ _GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
 						    g_new0
 						    (GSwitchItPluginManagerRecord,
 						     1);
-						XklDebug (100,
+						xkl_debug (100,
 							  "Loaded plugin from [%s]: [%s]/[%s]...\n",
 							  fullPath,
 							  plugin->name,
@@ -84,12 +84,12 @@ _GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
 						continue;
 					}
 				} else
-					XklDebug (0,
+					xkl_debug (0,
 						  "Bad plugin: [%s]\n",
 						  fullPath);
 				g_module_close (module);
 			} else
-				XklDebug (0, "Bad module: [%s], %s\n",
+				xkl_debug (0, "Bad module: [%s], %s\n",
 					  fullPath, g_module_error());
 			g_free (fullPath);
 		}
@@ -98,22 +98,22 @@ _GSwitchItPluginManagerAddPluginsDir (GSwitchItPluginManager *
 }
 
 static void
-_GSwitchItPluginManagerLoadAll (GSwitchItPluginManager * manager)
+_GSwitchItPluginManagerLoadAll (GSwitchItPluginManager *manager)
 {
 	if (!g_module_supported ()) {
-		XklDebug (0, "Modules are not supported - no plugins!\n");
+		xkl_debug (0, "Modules are not supported - no plugins!\n");
 		return;
 	}
 	_GSwitchItPluginManagerAddPluginsDir (manager, SYS_PLUGIN_DIR);
 }
 
 static void
-_GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *
-				rec, void *userData)
+_GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *rec,
+				void *userData)
 {
 	const GSwitchItPlugin *plugin = rec->plugin;
 	if (plugin != NULL) {
-		XklDebug (100, "Terminating plugin: [%s]...\n",
+		xkl_debug (100, "Terminating plugin: [%s]...\n",
 			  plugin->name);
 		if (plugin->termCallback)
 			(*plugin->termCallback) ();
@@ -121,16 +121,16 @@ _GSwitchItPluginManagerRecTerm (GSwitchItPluginManagerRecord *
 }
 
 static void
-_GSwitchItPluginManagerRecDestroy (GSwitchItPluginManagerRecord * rec)
+_GSwitchItPluginManagerRecDestroy (GSwitchItPluginManagerRecord *rec)
 {
-	XklDebug (100, "Unloading plugin: [%s]...\n", rec->plugin->name);
+	xkl_debug (100, "Unloading plugin: [%s]...\n", rec->plugin->name);
 
 	g_module_close (rec->module);
 	g_free (rec);
 }
 
 void
-GSwitchItPluginManagerInit (GSwitchItPluginManager * manager)
+GSwitchItPluginManagerInit (GSwitchItPluginManager *manager)
 {
 	manager->allPluginRecs =
 	    g_hash_table_new_full (g_str_hash, g_str_equal,
@@ -141,7 +141,7 @@ GSwitchItPluginManagerInit (GSwitchItPluginManager * manager)
 }
 
 void
-GSwitchItPluginManagerTerm (GSwitchItPluginManager * manager)
+GSwitchItPluginManagerTerm (GSwitchItPluginManager *manager)
 {
 	GSwitchItPluginManagerTermInitializedPlugins (manager);
 	if (manager->allPluginRecs != NULL) {
@@ -151,15 +151,14 @@ GSwitchItPluginManagerTerm (GSwitchItPluginManager * manager)
 }
 
 void
-GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
-					  manager,
-					  GSwitchItPluginContainer *
-					  pc, GSList * enabledPlugins)
+GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *manager,
+					  GSwitchItPluginContainer *pc,
+					  GSList *enabledPlugins)
 {
 	GSList *pluginNameNode = enabledPlugins;
 	if (manager->allPluginRecs == NULL)
 		return;
-	XklDebug (100, "Initializing all enabled plugins...\n");
+	xkl_debug (100, "Initializing all enabled plugins...\n");
 	while (pluginNameNode != NULL) {
 		const char *fullPath = pluginNameNode->data;
 		if (fullPath != NULL) {
@@ -172,7 +171,7 @@ GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
 				const GSwitchItPlugin *plugin =
 				    rec->plugin;
 				gboolean initialized = FALSE;
-				XklDebug (100,
+				xkl_debug (100,
 					  "Initializing plugin: [%s] from [%s]...\n",
 					  plugin->name, fullPath);
 				if (plugin->initCallback != NULL)
@@ -184,7 +183,7 @@ GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
 				manager->initedPluginRecs =
 				    g_slist_append (manager->
 						    initedPluginRecs, rec);
-				XklDebug (100,
+				xkl_debug (100,
 					  "Plugin [%s] initialized: %d\n",
 					  plugin->name, initialized);
 			}
@@ -194,8 +193,7 @@ GSwitchItPluginManagerInitEnabledPlugins (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *
-					      manager)
+GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *manager)
 {
 
 	if (manager->initedPluginRecs == NULL)
@@ -207,9 +205,9 @@ GSwitchItPluginManagerTermInitializedPlugins (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager * manager,
-				     GSwitchItPluginContainer * pc,
-				     GSList * enabledPlugins)
+GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager *manager,
+				     GSwitchItPluginContainer *pc,
+				     GSList *enabledPlugins)
 {
 	GSwitchItPluginManagerTermInitializedPlugins (manager);
 	GSwitchItPluginManagerInitEnabledPlugins (manager, pc,
@@ -217,17 +215,29 @@ GSwitchItPluginManagerTogglePlugins (GSwitchItPluginManager * manager,
 }
 
 void
-GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *
-				    manager, int newGroup)
+GSwitchItPluginManagerGroupChanged (GSwitchItPluginManager *manager,
+				    GtkWidget * notebook,
+				    int newGroup)
 {
-	FOR_EACH_INITED_PLUGIN ();
+	FOREACH_INITED_PLUGIN ();
 	if (plugin->groupChangedCallback)
-		(*plugin->groupChangedCallback) (newGroup);
-	END_FOR_EACH_INITED_PLUGIN ();
+		(*plugin->groupChangedCallback) (notebook, newGroup);
+	NEXT_INITED_PLUGIN ();
+}
+
+void
+GSwitchItPluginManagerConfigChanged (GSwitchItPluginManager *manager, 
+				     GSwitchItKbdConfig *from,
+				     GSwitchItKbdConfig *to)
+{
+	FOREACH_INITED_PLUGIN ();
+	if (plugin->configChangedCallback)
+		(*plugin->configChangedCallback) (from, to);
+	NEXT_INITED_PLUGIN ();
 }
 
 const GSwitchItPlugin *
-GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager * manager,
+GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager *manager,
 				 const char *fullPath)
 {
 	GSwitchItPluginManagerRecord *rec =
@@ -240,9 +250,8 @@ GSwitchItPluginManagerGetPlugin (GSwitchItPluginManager * manager,
 }
 
 void
-GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *
-				     manager,
-				     GSList * enabledPlugins,
+GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *manager,
+				     GSList *enabledPlugins,
 				     const char *fullPath)
 {
 	GSList *theNode = enabledPlugins;
@@ -263,9 +272,8 @@ GSwitchItPluginManagerPromotePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *
-				    manager,
-				    GSList * enabledPlugins,
+GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *manager,
+				    GSList *enabledPlugins,
 				    const char *fullPath)
 {
 	GSList *theNode = g_slist_find_custom (enabledPlugins, fullPath,
@@ -281,9 +289,8 @@ GSwitchItPluginManagerDemotePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *
-				    manager,
-				    GSList ** pEnabledPlugins,
+GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *manager,
+				    GSList **pEnabledPlugins,
 				    const char *fullPath)
 {
 	if (NULL != GSwitchItPluginManagerGetPlugin (manager, fullPath)) {
@@ -294,9 +301,8 @@ GSwitchItPluginManagerEnablePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *
-				     manager,
-				     GSList ** pEnabledPlugins,
+GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *manager,
+				     GSList **pEnabledPlugins,
 				     const char *fullPath)
 {
 	GSList *theNode = g_slist_find_custom (*pEnabledPlugins, fullPath,
@@ -309,56 +315,54 @@ GSwitchItPluginManagerDisablePlugin (GSwitchItPluginManager *
 }
 
 int
-GSwitchItPluginManagerWindowCreated (GSwitchItPluginManager *
-				     manager, Window win, Window parent)
+GSwitchItPluginManagerWindowCreated (GSwitchItPluginManager *manager,
+				     Window win,
+				     Window parent)
 {
-	FOR_EACH_INITED_PLUGIN ();
+	FOREACH_INITED_PLUGIN ();
 	if (plugin->windowCreatedCallback) {
 		int groupToAssign =
 		    (*plugin->windowCreatedCallback) (win, parent);
 		if (groupToAssign != -1) {
-			XklDebug (100,
+			xkl_debug (100,
 				  "Plugin [%s] assigned group %d to new window %ld\n",
 				  plugin->name, groupToAssign, win);
 			return groupToAssign;
 		}
 	}
-	END_FOR_EACH_INITED_PLUGIN ();
+	NEXT_INITED_PLUGIN ();
 	return -1;
 }
 
 GtkWidget *
-GSwitchItPluginManagerDecorateWidget (GSwitchItPluginManager *
-				      manager,
-				      GtkWidget * widget,
+GSwitchItPluginManagerDecorateWidget (GSwitchItPluginManager *manager,
+				      GtkWidget *widget,
 				      const gint group,
-				      const char
-				      *groupDescription,
-				      GSwitchItKbdConfig * kbdConfig)
+				      const char *groupDescription,
+				      GSwitchItKbdConfig *kbdConfig)
 {
-	FOR_EACH_INITED_PLUGIN ();
+	FOREACH_INITED_PLUGIN ();
 	if (plugin->decorateWidgetCallback) {
 		GtkWidget *decoratedWidget =
 		    (*plugin->decorateWidgetCallback) (widget, group,
 						       groupDescription,
 						       kbdConfig);
 		if (decoratedWidget != NULL) {
-			XklDebug (100,
+			xkl_debug (100,
 				  "Plugin [%s] decorated widget %p to %p\n",
 				  plugin->name, widget, decoratedWidget);
 			return decoratedWidget;
 		}
 	}
-	END_FOR_EACH_INITED_PLUGIN ();
+	NEXT_INITED_PLUGIN ();
 	return NULL;
 }
 
 void
-GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *
-				       manager,
-				       GSwitchItPluginContainer * pc,
+GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *manager,
+				       GSwitchItPluginContainer *pc,
 				       const char *fullPath,
-				       GtkWindow * parent)
+				       GtkWindow *parent)
 {
 	const GSwitchItPlugin *plugin =
 	    GSwitchItPluginManagerGetPlugin (manager, fullPath);
@@ -367,21 +371,15 @@ GSwitchItPluginManagerConfigurePlugin (GSwitchItPluginManager *
 }
 
 void
-GSwitchItPluginContainerInit (GSwitchItPluginContainer * pc,
-			      GConfClient * confClient)
+GSwitchItPluginContainerInit (GSwitchItPluginContainer *pc,
+			      GConfClient *confClient)
 {
 	pc->confClient = confClient;
 	g_object_ref (pc->confClient);
 }
 
 void
-GSwitchItPluginContainerTerm (GSwitchItPluginContainer * pc)
+GSwitchItPluginContainerTerm (GSwitchItPluginContainer *pc)
 {
 	g_object_unref (pc->confClient);
 }
-
-guint
-GSwitchItPluginGetNumGroups (GSwitchItPluginContainer * pc)
-{
-	return XklGetNumGroups ();
-}
