@@ -471,8 +471,6 @@ gnome_volume_applet_dispose (GObject *object)
       GstElement *element = GST_ELEMENT (item->data);
 
       gst_element_set_state (element, GST_STATE_NULL);
-      g_free (g_object_get_data (G_OBJECT (element),
-				 "gnome-volume-applet-name"));
       gst_object_unref (GST_OBJECT (element));
     }
     g_list_free (applet->elements);
@@ -1066,7 +1064,7 @@ gnome_volume_applet_refresh (GnomeVolumeApplet *applet,
       mute = TRUE;
 
     /* select image */
-    n = 4 * volume / 100 + 1;
+    n = 3 * volume / 100 + 2;
     if (n <= 0)
       n = 1;
     if (n >= 5)
@@ -1282,17 +1280,27 @@ cb_verb (BonoboUIComponent *uic,
     const gchar *authors[] = { "Ronald Bultje <rbultje@ronald.bitfreak.net>",
 			     NULL };
 
+    char *comments = g_strdup_printf ("%s\n\n%s",
+		    _("Volume control for your GNOME Panel."),
+#ifdef HAVE_GST10
+		    _("Using GStreamer 0.10.")
+#else
+		    _("Using GStreamer 0.8.")
+#endif
+		    );
+
     gtk_show_about_dialog (NULL,
 		"name",		_("Volume Applet"),
 		"version",	VERSION,
 		"copyright",	"\xC2\xA9 2004 Ronald Bultje",
-		"comments",	_("A GNOME/GStreamer-based volume control "
-				  "applet"),
+		"comments",	comments,
 		"authors",	authors,
 		"translator-credits",	_("translator-credits"),
 		"logo-icon-name",	"volume-knob",
 		NULL);
 
+    g_free (comments);
+
   } else if (!strcmp (verbname, "Pref")) {
     if (!applet->mixer) {
       show_no_mixer_dialog (applet);
